###Todo

* AbstractFitter should take mapping object that maps x values to some range
* Chebychev fitter
* Constrained nlsf fitter
* 2D fitter
* ~~Spherical Harmonic Fitter~~
* LSF to use numpy's algorithm instead of slower/less stable A.I for inversion
